@@ -1,6 +1,6 @@
 /* arp.c - ARP state machine */
  
-/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1995-2000 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdlib.h>
@@ -260,10 +260,11 @@ static void inarp_request(ENTRY *entry)
     ITF *itf;
 
     diag(COMPONENT,DIAG_DEBUG,"sending an InARP request for each IP interface");
-    for (vcc = entry->vccs; vcc; vcc = vcc->next)
-	if (!vcc->connecting)
-	    if (entry->itf) inarp_for_itf(vcc,entry->itf);
-	    else for (itf = itfs; itf; itf = itf->next) inarp_for_itf(vcc,itf);
+    for (vcc = entry->vccs; vcc; vcc = vcc->next) {
+	if (vcc->connecting) continue;
+	if (entry->itf) inarp_for_itf(vcc,entry->itf);
+	else for (itf = itfs; itf; itf = itf->next) inarp_for_itf(vcc,itf);
+    }
 }
 
 
@@ -501,7 +502,7 @@ static void learn(VCC *vcc,uint32_t ip,struct sockaddr_atmsvc *addr)
      * If we still don't have an entry, we try to use the entry that already
      * belongs to the VCC (InARP), or we create a new one (ARP).
      */
-    if (!entry)
+    if (!entry) {
 	if (vcc) {
 	    entry = vcc->entry;
 	    if (!entry->itf) {
@@ -521,6 +522,7 @@ static void learn(VCC *vcc,uint32_t ip,struct sockaddr_atmsvc *addr)
 	    entry = alloc_entry(1);
 	    entry->flags = ATF_PUBL;
 	}
+    }
     if (!atmsvc_addr_in_use(*addr)) addr = NULL;
     if (entry->addr && addr && (entry->flags & ATF_PERM) &&
       !atm_equal((struct sockaddr *) entry->addr,(struct sockaddr *) addr,0,0))
@@ -574,9 +576,10 @@ static void learn(VCC *vcc,uint32_t ip,struct sockaddr_atmsvc *addr)
 	    connect_me(entry);
 	send_notifications(entry,1);
     }
-    if ((entry->flags & ATF_ARPSRV) || !(entry->flags & ATF_PERM))
+    if ((entry->flags & ATF_ARPSRV) || !(entry->flags & ATF_PERM)) {
 	if (entry->itf->arp_srv) START_TIMER(entry,CREVAL);
 	else START_TIMER(entry,SREVAL);
+    }
     entry->state = as_valid;
 }
 
@@ -708,17 +711,19 @@ static void set_addr(struct sockaddr_atmsvc *addr,void *num,void *sub,
 	      TL_LEN);
 	else {
 	    memcpy(addr->sas_addr.pub,num,num_tl & TL_LEN);
-	    if (sub)
+	    if (sub) {
 		if (sub_tl != ATM_ESA_LEN) {
 		    diag(COMPONENT,DIAG_ERROR,"bad ESA length (%d)",sub_tl);
 		    *addr->sas_addr.pub = 0;
 		}
 		else memcpy(addr->sas_addr.prv,sub,ATM_ESA_LEN);
+	    }
 	}
-    else if (num)
+    else if (num) {
 	    if (num_tl != ATM_ESA_LEN)
 		diag(COMPONENT,DIAG_ERROR,"bad ESA length (%d)",num_tl);
 	    else memcpy(addr->sas_addr.prv,num,ATM_ESA_LEN);
+	}
 }
 
 
@@ -879,16 +884,16 @@ static int ioctl_set_svc(ITF *itf,uint32_t ip,struct sockaddr_atmsvc *addr,
     entry->qos = *qos;
     entry->sndbuf = sndbuf;
     entry->flags = flags;
-    if (!(flags & ATF_PERM) || (flags & ATF_ARPSRV))
+    if (!(flags & ATF_PERM) || (flags & ATF_ARPSRV)) {
 	if (itf->arp_srv) START_TIMER(entry,CREVAL);
 	else START_TIMER(entry,SREVAL);
+    }
     entry->itf = itf;
     Q_INSERT_HEAD(itf->table,entry);
-    if (flags & ATF_ARPSRV) {
-	entry->state = as_invalid;
-	itf->arp_srv = entry;
-	(void) want_arp_srv(itf);
-    }
+    if (!(flags & ATF_ARPSRV)) return 0;
+    entry->state = as_invalid;
+    itf->arp_srv = entry;
+    (void) want_arp_srv(itf);
     return 0;
 }
 
@@ -1000,10 +1005,9 @@ void vcc_failed(VCC *vcc)
     }
     for (entry = vcc->entry->itf->table; entry; entry = next) {
 	next = entry->next;
-	if (entry != vcc->entry && entry->state == as_resolv)
-	    if (entry->vccs || (entry->flags & ATF_PERM))
-		entry->state = as_invalid;
-	    else discard_entry(entry);
+	if (entry == vcc->entry || entry->state != as_resolv) continue;
+	if (entry->vccs || (entry->flags & ATF_PERM)) entry->state = as_invalid;
+	else discard_entry(entry);
     }
     START_TIMER(vcc->entry,RETRY);
     free(vcc);
