@@ -14,7 +14,7 @@
 #include <string.h>
 #include <netinet/in.h>
 
-#include <linux/atm.h>
+#include <atm.h>
 
 /* Local includes */
 #include "atmsap.h"
