@@ -1,6 +1,6 @@
 /* esi.c - Get or set End System Identifier (ESI) */
 
-/* Written 1997,1998 by Werner Almesberger, EPFL LRC/ICA */
+/* Written 1997-2000 by Werner Almesberger, EPFL LRC/ICA */
 
 
 #include <linux/version.h>
@@ -64,12 +64,13 @@ int main(int argc,char **argv)
 	if (*end) usage(*argv);
 	esi = argv[optind];
     }
-    if (argc == optind+1)
+    if (argc == optind+1) {
 	if (strlen(argv[optind]) == ESI_LEN*2) esi = argv[optind];
 	else {
 	    req.number = strtoul(argv[optind],&end,0);
 	    if (*end) usage(*argv);
 	}
+    }
     if (op == ATM_SETESIF && !esi) usage(*argv);
     if (esi) {
 	int i,byte;
