@@ -1,6 +1,6 @@
 /* common.h - Common definitions */
  
-/* Written 1995 by Werner Almesberger, EPFL-LRC */
+/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
  
 
 #ifndef COMMON_H
@@ -13,6 +13,7 @@
 
 
 extern int debug;
+extern int dump;
 
 
 void *alloc(size_t size);
