@@ -1,6 +1,6 @@
 /* isp.c - Internal Signaling Protocol test generator */
 
-/* Written 1997,1998 by Werner Almesberger, EPFL-ICA */
+/* Written 1997-2000 by Werner Almesberger, EPFL-ICA */
 
 
 #include <stdlib.h>
@@ -110,7 +110,7 @@ void print_value(VALUE val)
 	    printf("\"%s\"",val.u.text);
 	    return;
 	case vt_vcc:
-	    printf("%d (0x%x)",val.u.num,val.u.num);
+	    printf("%s",kptr_print(&val.u.id));
 	    return;
 	case vt_error:
 	    printf("%s",errno2str(val.u.num));
@@ -245,7 +245,8 @@ static VALUE convert(VALUE in,VALUE_TYPE type)
     out.type = type;
     switch (type) {
 	case vt_vcc:
-	    out.u.num = strtoul(in.u.text,&end,0);
+	    memset(&out.u.id,0,sizeof(out.u.id));
+	    *(unsigned long *) &out.u.id = strtoul(in.u.text,&end,0);
 	    if (*end) yyerror("invalid number");
 	    break;
 	case vt_error:
@@ -290,7 +291,7 @@ void check(VALUE a,VALUE b)
     switch (a.type) {
 	case vt_vcc:
 	case vt_error:
-	    if (a.u.num == b.u.num) return;
+	    if (kptr_eq(&a.u.id,&b.u.id)) return;
 	    break;
 	case vt_svc:
 	    if (atm_equal((struct sockaddr *) &a.u.svc,
@@ -321,8 +322,8 @@ void check(VALUE a,VALUE b)
 
 #define COPY_MSG_VAL(V) \
   switch (field) { \
-    case F_VCC:		_COPY(V.u.num,msg->vcc); break; \
-    case F_LISTEN_VCC:	_COPY(V.u.num,msg->listen_vcc); break; \
+    case F_VCC:		_COPY(V.u.id,msg->vcc); break; \
+    case F_LISTEN_VCC:	_COPY(V.u.id,msg->listen_vcc); break; \
     case F_REPLY:	_COPY(V.u.num,msg->reply); break; \
     case F_PVC:		_COPY(V.u.pvc,msg->pvc); break; \
     case F_LOCAL:	_COPY(V.u.svc,msg->local); break; \
